==> RSTouchscreenNG-0.94.3.zip: RSTouchscreenNG/projects/pages/src/lib/hardware-info.component.ts <==
/* (C) 2016-2020 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {
  ServerState
} from "binding";
import {select} from "@angular-redux/store";
import {Observable, SubscriptionLike} from "rxjs";

@Component({
  selector: "rs-hardware-info-component",
  template: `
<rs-page>
<rs-side>
    <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
</rs-side>
<rs-side>
  <rs-sideicon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
</rs-side>
<main>
<div >
    <rs-headline><i class="fa fa-bolt"></i> <?php _('Hardware Info') ?></rs-headline>
    <div class="content-h1 margin-leftright" rsDrag>
    <div class="regular-grid margin-leftright">
    <div *ngFor="let hi of server.hardwareInfos" class="value-list w100">
        <div><i class="{{hi.iconClass}}" style="width:2em"></i> {{hi.content}}</div>
    </div>
    </div>
    </div>
</div>
</main>
</rs-page>
    `
})
export class HardwareInfoComponent implements OnDestroy {
  server: ServerState;

  @select("server") server$: Observable<ServerState>;

  private serverSubscription: SubscriptionLike;

  constructor() {
    this.serverSubscription = this.server$.subscribe((s: ServerState) => {
      this.server = s;
    });
  }

  ngOnDestroy(): void {
    this.serverSubscription.unsubscribe();
  }
}

==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/pages/src/lib/hardware-info.component.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {
  RepetierState,
  ServerState
} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  selector: "rs-hardware-info-component",
  template: `
<rs-page>
<rs-side>
    <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
</rs-side>
<rs-side>
  <rs-sideicon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
</rs-side>
<main>
<div >
    <rs-headline><i class="fa fa-bolt"></i> <?php _('Hardware Info') ?></rs-headline>
    <div class="content-h1 margin-leftright" rsDrag>
    <div class="regular-grid margin-leftright">
    <div *ngFor="let hi of server.hardwareInfos" class="value-list w100">
        <div><i class="{{hi.iconClass}}" style="width:2em"></i> {{hi.content}}</div>
    </div>
    </div>
    </div>
</div>
</main>
</rs-page>
    `
})
export class HardwareInfoComponent implements OnDestroy {
  server: ServerState;

  server$: Observable<ServerState>;

  private serverSubscription: SubscriptionLike;

  constructor(private store: Store<RepetierState>) {
    this.server$ = store.select('server');
    this.serverSubscription = this.server$.subscribe((s: ServerState) => {
      this.server = s;
    });
  }

  ngOnDestroy(): void {
    this.serverSubscription.unsubscribe();
  }
}
